@@ -25,13 +25,12 @@ import (
 	objectbucket "github.com/kube-object-storage/lib-bucket-provisioner/pkg/apis/objectbucket.io/v1alpha1"
 	routev1 "github.com/openshift/api/route/v1"
 	"gopkg.in/yaml.v2"
-	appsv1 "k8s.io/api/apps/v1"
+	batchv1 "k8s.io/api/batch/v1"
 	corev1 "k8s.io/api/core/v1"
 	"k8s.io/apimachinery/pkg/api/errors"
 	"k8s.io/apimachinery/pkg/api/meta"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	"k8s.io/apimachinery/pkg/runtime"
-	k8sruntime "k8s.io/apimachinery/pkg/runtime"
 	"k8s.io/apimachinery/pkg/runtime/schema"
 	"k8s.io/apimachinery/pkg/types"
 	"k8s.io/apimachinery/pkg/util/wait"
@@ -64,8 +63,7 @@ type QuayRegistryReconciler struct {
 // +kubebuilder:rbac:groups=quay.redhat.com,resources=quayregistries,verbs=get;list;watch;create;update;patch;delete
 // +kubebuilder:rbac:groups=quay.redhat.com,resources=quayregistries/status,verbs=get;update;patch
 
-func (r *QuayRegistryReconciler) Reconcile(req ctrl.Request) (ctrl.Result, error) {
-	ctx := context.Background()
+func (r *QuayRegistryReconciler) Reconcile(ctx context.Context, req ctrl.Request) (ctrl.Result, error) {
 	log := r.Log.WithValues("quayregistry", req.NamespacedName)
 
 	log.Info("begin reconcile")
@@ -281,23 +279,17 @@ func (r *QuayRegistryReconciler) Reconcile(req ctrl.Request) (ctrl.Result, error
 
 		go func(quayRegistry *v1.QuayRegistry) {
 			err = wait.Poll(upgradePollInterval, upgradePollTimeout, func() (bool, error) {
-				log.Info("checking Quay upgrade deployment readiness")
+				log.Info("checking Quay upgrade `Job` completion")
 
-				var upgradeDeployment appsv1.Deployment
-				err = r.Client.Get(ctx, types.NamespacedName{Name: quayRegistry.GetName() + "-quay-app-upgrade", Namespace: quayRegistry.GetNamespace()}, &upgradeDeployment)
+				var upgradeJob batchv1.Job
+				err = r.Client.Get(ctx, types.NamespacedName{Name: quayRegistry.GetName() + "-quay-app-upgrade", Namespace: quayRegistry.GetNamespace()}, &upgradeJob)
 				if err != nil {
-					log.Error(err, "could not retrieve Quay upgrade deployment during upgrade")
+					log.Error(err, "could not retrieve Quay upgrade `Job`")
 
 					return false, err
 				}
 
-				if upgradeDeployment.Spec.Size() < 1 {
-					log.Info("upgrade deployment scaled down, skipping check")
-
-					return true, nil
-				}
-
-				if upgradeDeployment.Status.ReadyReplicas > 0 {
+				if upgradeJob.Status.Succeeded > 0 {
 					log.Info("Quay upgrade complete, updating `status.currentVersion`")
 
 					updatedQuay, _ := v1.EnsureRegistryEndpoint(quayContext, updatedQuay, userProvidedConfig)
@@ -331,11 +323,12 @@ func (r *QuayRegistryReconciler) Reconcile(req ctrl.Request) (ctrl.Result, error
 
 					return true, nil
 				}
+
 				return false, nil
 			})
 
 			if err != nil {
-				log.Error(err, "Quay upgrade deployment never reached ready phase")
+				log.Error(err, "Quay upgrade `Job` never completed")
 			}
 		}(updatedQuay.DeepCopy())
 	}
@@ -356,7 +349,7 @@ func decode(bytes []byte) interface{} {
 	return value
 }
 
-func (r *QuayRegistryReconciler) createOrUpdateObject(ctx context.Context, obj k8sruntime.Object, quay v1.QuayRegistry) error {
+func (r *QuayRegistryReconciler) createOrUpdateObject(ctx context.Context, obj client.Object, quay v1.QuayRegistry) error {
 	objectMeta, _ := meta.Accessor(obj)
 	groupVersionKind := obj.GetObjectKind().GroupVersionKind().String()
 
